# Welcome

Qlue-ls (pronounced *clueless*) is a Language Server for SPARQL.
It's written in Rust and build for the web.

<div class="grid cards" markdown>

-   :material-fire:{ .lg .middle } __Powerful capabilities__

    ---

    Learn about what Qlue-ls can do to make your life easier.

    [:octicons-arrow-right-24: capabilities](/03_capabilities)

-   :material-connection:{ .lg .middle } __Collect to a backend__

    ---

    Qlue-ls can connect to a triple store to retrieve information.

    [:octicons-arrow-right-24: Customization](#)

-   :material-tools:{ .lg .middle } __Customize Completion__

    ---

    Help Qlue-ls to provide  the best completion suggestions possible.

    [:octicons-arrow-right-24: completion queries](/06_completion_queries)

-   :material-scale-balance:{ .lg .middle } __Open Source, MIT__

    ---

    Qlue-ls is licensed under MIT and available on [GitHub](https://github.com/IoannisNezis/Qlue-ls)

    [:octicons-arrow-right-24: License](https://github.com/IoannisNezis/Qlue-ls/blob/main/LICENSE)

</div>


